# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['qvapay',
 'qvapay.v1',
 'qvapay.v1._async',
 'qvapay.v1._sync',
 'qvapay.v1.models']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.20.0,<0.21.0',
 'python-dateutil>=2.8.2,<3.0.0',
 'python-dotenv>=0.19.1,<0.20.0']

setup_kwargs = {
    'name': 'qvapay',
    'version': '0.3.0',
    'description': 'Python SDK for the QvaPay API',
    'long_description': '# Python SDK for the QvaPay API\n\n![Banner](https://raw.githubusercontent.com/lugodev/qvapay-python/main/banner.jpg)\n\nNon official, but friendly QvaPay library for the Python language.\n\n[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)\n[![Test](https://github.com/lugodev/qvapay-python/workflows/CI/badge.svg)](https://github.com/lugodev/qvapay-python/actions?query=workflow%3ACI)\n[![codecov](https://codecov.io/gh/lugodev/qvapay-python/branch/main/graph/badge.svg)](https://codecov.io/gh/lugodev/qvapay-python)\n[![Version](https://img.shields.io/pypi/v/qvapay?color=%2334D058&label=Version)](https://pypi.org/project/qvapay)\n[![Last commit](https://img.shields.io/github/last-commit/lugodev/qvapay-python.svg?style=flat)](https://github.com/lugodev/qvapay-python/commits)\n[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/lugodev/qvapay-python)](https://github.com/lugodev/qvapay-python/commits)\n[![Github Stars](https://img.shields.io/github/stars/lugodev/qvapay-python?style=flat&logo=github)](https://github.com/lugodev/qvapay-python/stargazers)\n[![Github Forks](https://img.shields.io/github/forks/lugodev/qvapay-python?style=flat&logo=github)](https://github.com/lugodev/qvapay-python/network/members)\n[![Github Watchers](https://img.shields.io/github/watchers/lugodev/qvapay-python?style=flat&logo=github)](https://github.com/lugodev/qvapay-python)\n[![GitHub contributors](https://img.shields.io/github/contributors/lugodev/qvapay-python?label=code%20contributors)](https://github.com/lugodev/qvapay-python/graphs/contributors)<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->\n[![All Contributors](https://img.shields.io/badge/all_contributors-5-orange.svg?style=flat-square)](#contributors-)\n<!-- ALL-CONTRIBUTORS-BADGE:END -->\n\n## Setup\n\nYou can install this package by using the pip tool and installing:\n\n```bash\npip install qvapay\n```\n\nOr\n\n```bash\neasy_install qvapay\n```\n\n## Sign up on **QvaPay**\n\nCreate your account to process payments through **QvaPay** at [qvapay.com/register](https://qvapay.com/register).\n\n## Using the client\n\nFirst, import the `AsyncQvaPayClient` (or `SyncQvaPayClient`) class and create your **QvaPay** asynchronous (or synchronous) client using your app credentials.\n\n```python\nfrom qvapay.v1 import AsyncQvaPayClient\n\nclient = AsyncQvaPayClient(app_id, app_secret)\n```\n\nIt is also possible to use the `QvaPayAuth` class (which by default obtains its properties from environment variables or from the content of the `.env` file) and the static method `AsyncQvaPayClient.from_auth` (or `SyncQvaPayClient.from_auth`) to initialize the client.\n\n```python\nfrom qvapay.v1 import AsyncQvaPayClient, QvaPayAuth\n\nclient = AsyncQvaPayClient.from_auth(QvaPayAuth())\n```\n\n### Use context manager\n\nThe recommended way to use a client is as a context manager. For example:\n\n```python\nasync with AsyncQvaPayClient(...) as client:\n    # Do anything you want\n    ...\n```\n\nor\n\n```python\nwith SyncQvaPayClient(...) as client:\n    # Do anything you want\n    ...\n```\n\n### Get your app info\n\n```python\n# Use await when using AsyncQvaPayClient\n# With SyncQvaPayClient it is not necessary.\ninfo = await client.get_info()\n```\n\n### Get your account balance\n\n```python\n# Use await when using AsyncQvaPayClient\n# With SyncQvaPayClient it is not necessary.\nbalance = await client.get_balance()\n```\n\n### Create an invoice\n\n```python\n# Use await when using AsyncQvaPayClient\n# With SyncQvaPayClient it is not necessary.\ntransaction = await client.create_invoice(\n    amount=10,\n    description=\'Ebook\',\n    remote_id=\'EE-BOOk-123\' # example remote invoice id\n)\n```\n\n### Get transaction\n\n```python\n# Use await when using AsyncQvaPayClient\n# With SyncQvaPayClient it is not necessary.\ntransaction = await client.get_transaction(id)\n```\n\n### Get transactions\n\n```python\n# Use await when using AsyncQvaPayClient\n# With SyncQvaPayClient it is not necessary.\ntransactions = await client.get_transactions(page=1)\n```\n\nYou can also read the **QvaPay API** documentation: [qvapay.com/docs](https://qvapay.com/docs).\n\n## For developers\n\nThe `_sync` folders were generated automatically executing the command `unasync qvapay tests`.\n\nThe code that is added in the `_async` folders is automatically transformed.\n\nSo every time to make a change you must run the command `unasync qvapay tests` to regenerate the folders `_sync` with the synchronous version of the implementation.\n\nImprove `tests` implementation and add `pre-commit` system to ensure format and style.\n\n## Migration guide\n\n### 0.2.0 -> 0.3.0\n\n- `QvaPayClient` was divided into two classes: `AsyncQvaPayClient` and `SyncQvaPayClient`. Both classes have the same methods and properties, with the difference that the methods in `AsyncQvaPayClient` are asynchronous and in `SyncQvaPayClient` are synchronous.\n\n### 0.1.0 -> 0.2.0\n\n- `user_id` of `Transaction` model was removed\n- `paid_by_user_id` of `Transaction` model was removed\n\n### 0.0.3 -> 0.1.0\n\n- `from qvapay.v1 import *` instead of `from qvapay import *`\n- `QvaPayClient` instead of `Client`\n- `client.get_info` instead of `client.info`\n- `client.get_balance` instead of `client.balance`\n- `client.get_transactions` instead of `client.transactions`\n\n## Contributors ✨\n\nThanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):\n\n<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->\n<!-- prettier-ignore-start -->\n<!-- markdownlint-disable -->\n<table>\n  <tr>\n    <td align="center"><a href="https://bio.link/lugodev"><img src="https://avatars.githubusercontent.com/u/18733370?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Carlos Lugones</b></sub></a><br /><a href="https://github.com/lugodev/qvapay-python/commits?author=lugodev" title="Code">💻</a></td>\n    <td align="center"><a href="http://codeshard.github.io/"><img src="https://avatars.githubusercontent.com/u/5880754?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Ozkar L. Garcell</b></sub></a><br /><a href="https://github.com/lugodev/qvapay-python/commits?author=codeshard" title="Code">💻</a></td>\n    <td align="center"><a href="https://github.com/leynier"><img src="https://avatars.githubusercontent.com/u/36774373?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Leynier Gutiérrez González</b></sub></a><br /><a href="https://github.com/lugodev/qvapay-python/commits?author=leynier" title="Code">💻</a></td>\n    <td align="center"><a href="https://github.com/jorgeajimenezl"><img src="https://avatars.githubusercontent.com/u/18174581?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Jorge Alejandro Jimenez Luna</b></sub></a><br /><a href="https://github.com/lugodev/qvapay-python/commits?author=jorgeajimenezl" title="Code">💻</a></td>\n    <td align="center"><a href="https://blog.ragnarok22.dev"><img src="https://avatars.githubusercontent.com/u/8838803?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Reinier Hernández</b></sub></a><br /><a href="https://github.com/lugodev/qvapay-python/issues?q=author%3Aragnarok22" title="Bug reports">🐛</a></td>\n  </tr>\n</table>\n\n<!-- markdownlint-restore -->\n<!-- prettier-ignore-end -->\n\n<!-- ALL-CONTRIBUTORS-LIST:END -->\n\nThis project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!\n\n<p align="center">\n    <img src="http://ForTheBadge.com/images/badges/made-with-python.svg">\n</p>\n',
    'author': 'Carlos Lugones',
    'author_email': 'contact@lugodev.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lugodev/qvapay-python',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
